.. _utils:

Tax-Brain Utilities
======================================

**utils**

taxbrain.utils
------------------------------------------

.. currentmodule:: taxbrain.utils

.. automodule:: taxbrain.utils
  :members: weighted_sum, distribution_plot, differences_plot,
    update_policy, is_paramtools_format, lorenz_data, lorenz_curve,
    volcano_plot
